package com.ruoyi.cs.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.cs.domain.CsExpansionRecord;
import com.ruoyi.cs.domain.CsMessageInfo;

/**
 * 扩容记录Service接口
 * 
 * @author ruoyi
 * @date 2024-05-29
 */
public interface ICsExpansionRecordService 
{
    /**
     * 查询扩容记录
     * 
     * @param expansionRecordId 扩容记录主键
     * @return 扩容记录
     */
    public CsExpansionRecord selectCsExpansionRecordByExpansionRecordId(String expansionRecordId);

    /**
     * 查询扩容记录列表
     * 
     * @param csExpansionRecord 扩容记录
     * @return 扩容记录集合
     */
    public List<CsExpansionRecord> selectCsExpansionRecordList(CsExpansionRecord csExpansionRecord);

    /**
     * 新增扩容记录
     * 
     * @param csExpansionRecord 扩容记录
     * @return 结果
     */
    public int insertCsExpansionRecord(CsExpansionRecord csExpansionRecord);

    /**
     * 修改扩容记录
     * 
     * @param csExpansionRecord 扩容记录
     * @return 结果
     */
    public int updateCsExpansionRecord(CsExpansionRecord csExpansionRecord);

    /**
     * 批量删除扩容记录
     * 
     * @param expansionRecordIds 需要删除的扩容记录主键集合
     * @return 结果
     */
    public int deleteCsExpansionRecordByExpansionRecordIds(String[] expansionRecordIds);

    /**
     * 删除扩容记录信息
     * 
     * @param expansionRecordId 扩容记录主键
     * @return 结果
     */
    public int deleteCsExpansionRecordByExpansionRecordId(String expansionRecordId);

    /**
     * 查询消息列表
     *
     * @param csMessageInfo
     * @return
     */
    List<CsMessageInfo> searchMessageList(CsMessageInfo csMessageInfo);

    /**
     * 查询用户列表
     *
     * @return
     */
    List<Map<String,Object>> searchMemberList();

    /**
     * 查询单位列表
     *
     * @return
     */
    List<Map<String,Object>> searchCompanyList();

    /**
     * 查询到期的扩容记录列表
     *
     * @return
     */
    List<CsExpansionRecord> searchExpansionMemberUserIdList();

    /**
     * 保存消息
     *
     * @param csMessageInfo
     * @return
     */
    int saveMessageInfo(CsMessageInfo csMessageInfo);

    /**
     * 根据业务ID查询消息数量
     *
     * @param businessId
     * @return
     */
    int searchMessageCountByBusinessId(String businessId);

}
